Documentation
¶
Overview ¶
Package slog contains a Logger type that satisfies cosmossdk.io/log.Logger, backed by a standard library *log/slog.Logger.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶
type Logger struct {
// contains filtered or unexported fields
}
Logger satisfies log.Logger with logging backed by an instance of *slog.Logger.
func NewCustomLogger ¶
NewCustomLogger returns a Logger backed by an existing slog.Logger instance. All logging methods are called directly on the *slog.Logger; therefore it is the caller's responsibility to configure message filtering, level filtering, output format, and so on.
Click to show internal directories.
Click to hide internal directories.